@@ -8,15 +8,14 @@ use Alien::Build::Plugin;
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: CMake plugin for Alien::Build
-our $VERSION = '0.04_02'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.02'; # VERSION
 
 
 sub cmake_generator
 {
   if($^O eq 'MSWin32')
   {
-    return 'MinGW Makefiles' if is_dmake();
+    return 'Unix Makefiles' if is_dmake();
   
     {
       my($out, $err) = capture { system $Config{make}, '/?' };
@@ -25,7 +24,7 @@ sub cmake_generator
 
     {
       my($out, $err) = capture { system $Config{make}, '--version' };
-      return 'MinGW Makefiles' if $out =~ /GNU Make/;
+      return 'Unix Makefiles' if $out =~ /GNU Make/;
     }
 
     die 'make not detected';
@@ -52,7 +51,7 @@ sub init
     # if we can find it!
     my $found_gnu_make = 0;
 
-    foreach my $exe (qw( gmake make mingw32-make ))
+    foreach my $exe (qw( gmake make ))
     {
       my($out, $err) = capture { system $exe, '--version' };
       if($out =~ /GNU Make/)
@@ -72,16 +71,9 @@ sub init
   $meta->interpolator->replace_helper('cmake' => sub { require Alien::cmake3; Alien::cmake3->exe });
   $meta->interpolator->add_helper('cmake_generator' => \&cmake_generator);
 
-  my @args = (
-    -G => '%{cmake_generator}', 
-    '-DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=true', 
-    '-DCMAKE_INSTALL_PREFIX:PATH=%{.install.prefix}', 
-    '-DCMAKE_MAKE_PROGRAM:PATH=%{make}',
-  );
-
   $meta->default_hook(
     build => [
-      ['%{cmake}', @args, '.' ],
+      ['%{cmake}', -G => '%{cmake_generator}', '-DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=true', '-DCMAKE_INSTALL_PREFIX:PATH=%{.install.prefix}', '.' ],
       ['%{make}' ],
       ['%{make}', 'install' ],
     ],
@@ -125,7 +117,7 @@ Alien::Build::Plugin::Build::CMake - CMake plugin for Alien::Build
 
 =head1 VERSION
 
-version 0.04_02
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -135,13 +127,7 @@ version 0.04_02
    plugin 'Build::CMake';
    build [
      # this is the default build step, if you do not specify one.
-     [ '%{cmake}', 
-         -G => '%{cmake_generator}', 
-         '-DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=true', 
-         '-DCMAKE_INSTALL_PREFIX:PATH=%{.install.prefix}', 
-         '-DCMAKE_MAKE_PROGRAM:PATH=%{make}', 
-         '.'
-     ],
+     [ '%{cmake}', -G => '%{cmake_generator}', '-DCMAKE_POSITION_INDEPENDENT_CODE:BOOL=true', '-DCMAKE_INSTALL_PREFIX:PATH=%{.install.prefix}', '.' ],
      '%{make}',
      '%{make} install',
    ];
